@@ -1,5 +1,5 @@
 from id_card_extractor.detect_neat_image import get_blur_value
 from id_card_extractor.detect_neat_image import get_glare_value
 from id_card_extractor.extractor import get_card_from_image
-from utils_extractor.label_map_util import *
-from utils_extractor.visualization_utils import *
\ No newline at end of file
+from id_card_extractor.utils_extractor.label_map_util import *
+from id_card_extractor.utils_extractor.visualization_utils import *
\ No newline at end of file
